@@ -31,3 +31,10 @@ Mapper.sqs_client = providers.Singleton(
         aws_secret_access_key=Core.config.aws.secret_access_key,
         region_name=Core.config.aws.region_name
     )
+Mapper.dynamodb_client = providers.Singleton(
+        boto3.client, 'dynamodb',
+        config=boto_client_config,
+        aws_access_key_id=Core.config.aws.access_key_id,
+        aws_secret_access_key=Core.config.aws.secret_access_key,
+        region_name=Core.config.aws.region_name
+    )
\ No newline at end of file
