@@ -1,5 +1,5 @@
 import abc
-from servicemapper.types import DataDialect, Operations
+from servicemapper.types import Constants, DataDialect, Operations, ServiceConnectorData
 
 class ServiceConnector(abc.ABC):
     TRANSLATION_MAP = {
@@ -21,27 +21,20 @@ class ServiceConnector(abc.ABC):
         raise NotImplementedError()
 
     @abc.abstractmethod
-    def translate_data(self, input_data: dict, input_dialect: DataDialect) -> (dict, DataDialect): # pragma: no cover
-        """Translate the data from the input dialect to the output dialect
-        
-        Arguments:
-            input_data {dict} -- Data from the input source
-            input_dialect {DataDialect} -- Dialect of the input data
-        
-        Returns:
-            (output_data, output_dialect) -- Tuple consisting of the output data and its dialect
-        """
+    def read_from_service(self) -> ServiceConnectorData: # pragma: no cover
         raise NotImplementedError()
 
     @abc.abstractmethod
-    def write_output_data(self, output_data: dict, operation: Operations) -> dict: # pragma: no cover
-        """Write the output data to the correct destination, depending on the operation
+    def translate_data(self, input_data: ServiceConnectorData) -> ServiceConnectorData: # pragma: no cover
+        """Translate the data from the input dialect to the output dialect
         
         Arguments:
-            output_data {dict} -- Data, in the correct format for the output destination
-            operation {Operation} -- Operation to perform
+            input_data {ServiceConnectorData} -- Data from the input source
         
         Returns:
-            dict -- Dictionary indicating results of the operation
+            output_data -- The output data
         """
-        raise NotImplementedError()
\ No newline at end of file
+        raise NotImplementedError()
+
+    def write_to_service(self, output_data: ServiceConnectorData) -> dict: # pragma: no cover
+        raise NotImplementedError()
